summaryrefslogtreecommitdiff
path: root/driver/xf86-video-rendition/src
diff options
context:
space:
mode:
authorMatthieu Herrb <matthieu@cvs.openbsd.org>2012-08-11 09:44:23 +0000
committerMatthieu Herrb <matthieu@cvs.openbsd.org>2012-08-11 09:44:23 +0000
commit151867feaf4c94de8eb55147220d3275f50d4415 (patch)
tree233e8c716a4a6676afbef039da53988b51c21ed9 /driver/xf86-video-rendition/src
parentc43e7ceebb837b849f00b1f715cdb857b2a8dab8 (diff)
Update to xf86-video-rendition 4.2.5
Diffstat (limited to 'driver/xf86-video-rendition/src')
-rw-r--r--driver/xf86-video-rendition/src/Makefile.am5
-rw-r--r--driver/xf86-video-rendition/src/Makefile.in405
-rw-r--r--driver/xf86-video-rendition/src/accelX.c16
-rw-r--r--driver/xf86-video-rendition/src/compat-api.h99
-rw-r--r--driver/xf86-video-rendition/src/hwcursor.c4
-rw-r--r--driver/xf86-video-rendition/src/hwcursor.h2
-rw-r--r--driver/xf86-video-rendition/src/rendition.c127
-rw-r--r--driver/xf86-video-rendition/src/rendition.h3
-rw-r--r--driver/xf86-video-rendition/src/rendition_shadow.c6
-rw-r--r--driver/xf86-video-rendition/src/rendition_shadow.h2
-rw-r--r--driver/xf86-video-rendition/src/v1krisc.c62
-rw-r--r--driver/xf86-video-rendition/src/vboard.c4
-rw-r--r--driver/xf86-video-rendition/src/vgafont-std.data1
-rw-r--r--driver/xf86-video-rendition/src/vgafont-vrx.data1
-rw-r--r--driver/xf86-video-rendition/src/vgapalette.data1
-rw-r--r--driver/xf86-video-rendition/src/vloaduc.c12
-rw-r--r--driver/xf86-video-rendition/src/vmodes.c11
-rw-r--r--driver/xf86-video-rendition/src/vos.h12
-rw-r--r--driver/xf86-video-rendition/src/vramdac.c36
-rw-r--r--driver/xf86-video-rendition/src/vtypes.h9
20 files changed, 511 insertions, 307 deletions
diff --git a/driver/xf86-video-rendition/src/Makefile.am b/driver/xf86-video-rendition/src/Makefile.am
index 5194089c8..06663773e 100644
--- a/driver/xf86-video-rendition/src/Makefile.am
+++ b/driver/xf86-video-rendition/src/Makefile.am
@@ -29,10 +29,9 @@ rendition_drv_la_LDFLAGS = -module -avoid-version
rendition_drv_ladir = @moduledir@/drivers
rendition_drv_la_SOURCES = \
- accel.h \
- accelX.c \
cmd2d.h \
commonregs.h \
+ compat-api.h \
cscode.h \
hwcursor.c \
hwcursor.h \
@@ -64,6 +63,8 @@ dist_driver_DATA = \
v20002d.uc
EXTRA_DIST = \
+ accel.h \
+ accelX.c \
README.uc \
vgafont-std.data \
vgafont-vrx.data \
diff --git a/driver/xf86-video-rendition/src/Makefile.in b/driver/xf86-video-rendition/src/Makefile.in
index 9ed58a034..a40f7a557 100644
--- a/driver/xf86-video-rendition/src/Makefile.in
+++ b/driver/xf86-video-rendition/src/Makefile.in
@@ -1,8 +1,8 @@
-# Makefile.in generated by automake 1.9.6 from Makefile.am.
+# Makefile.in generated by automake 1.12.2 from Makefile.am.
# @configure_input@
-# Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-# 2003, 2004, 2005 Free Software Foundation, Inc.
+# Copyright (C) 1994-2012 Free Software Foundation, Inc.
+
# This Makefile.in is free software; the Free Software Foundation
# gives unlimited permission to copy and/or distribute it,
# with or without modifications, as long as this notice is preserved.
@@ -35,15 +35,29 @@
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-srcdir = @srcdir@
-top_srcdir = @top_srcdir@
VPATH = @srcdir@
+am__make_dryrun = \
+ { \
+ am__dry=no; \
+ case $$MAKEFLAGS in \
+ *\\[\ \ ]*) \
+ echo 'am--echo: ; @echo "AM" OK' | $(MAKE) -f - 2>/dev/null \
+ | grep '^AM OK$$' >/dev/null || am__dry=yes;; \
+ *) \
+ for am__flg in $$MAKEFLAGS; do \
+ case $$am__flg in \
+ *=*|--*) ;; \
+ *n*) am__dry=yes; break;; \
+ esac; \
+ done;; \
+ esac; \
+ test $$am__dry = yes; \
+ }
pkgdatadir = $(datadir)/@PACKAGE@
-pkglibdir = $(libdir)/@PACKAGE@
pkgincludedir = $(includedir)/@PACKAGE@
-top_builddir = ..
+pkglibdir = $(libdir)/@PACKAGE@
+pkglibexecdir = $(libexecdir)/@PACKAGE@
am__cd = CDPATH="$${ZSH_VERSION+.}$(PATH_SEPARATOR)" && cd
-INSTALL = @INSTALL@
install_sh_DATA = $(install_sh) -c -m 644
install_sh_PROGRAM = $(install_sh) -c
install_sh_SCRIPT = $(install_sh) -c
@@ -59,43 +73,99 @@ build_triplet = @build@
host_triplet = @host@
subdir = src
DIST_COMMON = $(dist_driver_DATA) $(srcdir)/Makefile.am \
- $(srcdir)/Makefile.in
+ $(srcdir)/Makefile.in $(top_srcdir)/depcomp
ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
am__aclocal_m4_deps = $(top_srcdir)/configure.ac
am__configure_deps = $(am__aclocal_m4_deps) $(CONFIGURE_DEPENDENCIES) \
$(ACLOCAL_M4)
-mkinstalldirs = $(SHELL) $(install_sh) -d
+mkinstalldirs = $(install_sh) -d
CONFIG_HEADER = $(top_builddir)/config.h
CONFIG_CLEAN_FILES =
+CONFIG_CLEAN_VPATH_FILES =
am__vpath_adj_setup = srcdirstrip=`echo "$(srcdir)" | sed 's|.|.|g'`;
am__vpath_adj = case $$p in \
$(srcdir)/*) f=`echo "$$p" | sed "s|^$$srcdirstrip/||"`;; \
*) f=$$p;; \
esac;
-am__strip_dir = `echo $$p | sed -e 's|^.*/||'`;
+am__strip_dir = f=`echo $$p | sed -e 's|^.*/||'`;
+am__install_max = 40
+am__nobase_strip_setup = \
+ srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*|]/\\\\&/g'`
+am__nobase_strip = \
+ for p in $$list; do echo "$$p"; done | sed -e "s|$$srcdirstrip/||"
+am__nobase_list = $(am__nobase_strip_setup); \
+ for p in $$list; do echo "$$p $$p"; done | \
+ sed "s| $$srcdirstrip/| |;"' / .*\//!s/ .*/ ./; s,\( .*\)/[^/]*$$,\1,' | \
+ $(AWK) 'BEGIN { files["."] = "" } { files[$$2] = files[$$2] " " $$1; \
+ if (++n[$$2] == $(am__install_max)) \
+ { print $$2, files[$$2]; n[$$2] = 0; files[$$2] = "" } } \
+ END { for (dir in files) print dir, files[dir] }'
+am__base_list = \
+ sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
+ sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
+am__uninstall_files_from_dir = { \
+ test -z "$$files" \
+ || { test ! -d "$$dir" && test ! -f "$$dir" && test ! -r "$$dir"; } \
+ || { echo " ( cd '$$dir' && rm -f" $$files ")"; \
+ $(am__cd) "$$dir" && rm -f $$files; }; \
+ }
am__installdirs = "$(DESTDIR)$(rendition_drv_ladir)" \
"$(DESTDIR)$(driverdir)"
-rendition_drv_laLTLIBRARIES_INSTALL = $(INSTALL)
LTLIBRARIES = $(rendition_drv_la_LTLIBRARIES)
rendition_drv_la_LIBADD =
-am_rendition_drv_la_OBJECTS = accelX.lo hwcursor.lo rendition.lo \
+am_rendition_drv_la_OBJECTS = hwcursor.lo rendition.lo \
rendition_shadow.lo v1krisc.lo vboard.lo vloaduc.lo vmisc.lo \
vmodes.lo vramdac.lo
rendition_drv_la_OBJECTS = $(am_rendition_drv_la_OBJECTS)
-DEFAULT_INCLUDES = -I. -I$(srcdir) -I$(top_builddir)
+AM_V_lt = $(am__v_lt_@AM_V@)
+am__v_lt_ = $(am__v_lt_@AM_DEFAULT_V@)
+am__v_lt_0 = --silent
+am__v_lt_1 =
+rendition_drv_la_LINK = $(LIBTOOL) $(AM_V_lt) --tag=CC \
+ $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=link $(CCLD) \
+ $(AM_CFLAGS) $(CFLAGS) $(rendition_drv_la_LDFLAGS) $(LDFLAGS) \
+ -o $@
+AM_V_P = $(am__v_P_@AM_V@)
+am__v_P_ = $(am__v_P_@AM_DEFAULT_V@)
+am__v_P_0 = false
+am__v_P_1 = :
+AM_V_GEN = $(am__v_GEN_@AM_V@)
+am__v_GEN_ = $(am__v_GEN_@AM_DEFAULT_V@)
+am__v_GEN_0 = @echo " GEN " $@;
+am__v_GEN_1 =
+AM_V_at = $(am__v_at_@AM_V@)
+am__v_at_ = $(am__v_at_@AM_DEFAULT_V@)
+am__v_at_0 = @
+am__v_at_1 =
+DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
depcomp = $(SHELL) $(top_srcdir)/depcomp
am__depfiles_maybe = depfiles
+am__mv = mv -f
COMPILE = $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) \
$(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS)
-LTCOMPILE = $(LIBTOOL) --tag=CC --mode=compile $(CC) $(DEFS) \
+LTCOMPILE = $(LIBTOOL) $(AM_V_lt) --tag=CC $(AM_LIBTOOLFLAGS) \
+ $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) \
$(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) \
$(AM_CFLAGS) $(CFLAGS)
+AM_V_CC = $(am__v_CC_@AM_V@)
+am__v_CC_ = $(am__v_CC_@AM_DEFAULT_V@)
+am__v_CC_0 = @echo " CC " $@;
+am__v_CC_1 =
CCLD = $(CC)
-LINK = $(LIBTOOL) --tag=CC --mode=link $(CCLD) $(AM_CFLAGS) $(CFLAGS) \
+LINK = $(LIBTOOL) $(AM_V_lt) --tag=CC $(AM_LIBTOOLFLAGS) \
+ $(LIBTOOLFLAGS) --mode=link $(CCLD) $(AM_CFLAGS) $(CFLAGS) \
$(AM_LDFLAGS) $(LDFLAGS) -o $@
+AM_V_CCLD = $(am__v_CCLD_@AM_V@)
+am__v_CCLD_ = $(am__v_CCLD_@AM_DEFAULT_V@)
+am__v_CCLD_0 = @echo " CCLD " $@;
+am__v_CCLD_1 =
SOURCES = $(rendition_drv_la_SOURCES)
DIST_SOURCES = $(rendition_drv_la_SOURCES)
-dist_driverDATA_INSTALL = $(INSTALL_DATA)
+am__can_run_installinfo = \
+ case $$AM_UPDATE_INFO_DIR in \
+ n|no|NO) false;; \
+ *) (install-info --version) >/dev/null 2>&1;; \
+ esac
DATA = $(dist_driver_DATA)
ETAGS = etags
CTAGS = ctags
@@ -103,8 +173,6 @@ DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
ACLOCAL = @ACLOCAL@
ADMIN_MAN_DIR = @ADMIN_MAN_DIR@
ADMIN_MAN_SUFFIX = @ADMIN_MAN_SUFFIX@
-AMDEP_FALSE = @AMDEP_FALSE@
-AMDEP_TRUE = @AMDEP_TRUE@
AMTAR = @AMTAR@
AM_DEFAULT_VERBOSITY = @AM_DEFAULT_VERBOSITY@
APP_MAN_DIR = @APP_MAN_DIR@
@@ -114,6 +182,7 @@ AUTOCONF = @AUTOCONF@
AUTOHEADER = @AUTOHEADER@
AUTOMAKE = @AUTOMAKE@
AWK = @AWK@
+BASE_CFLAGS = @BASE_CFLAGS@
CC = @CC@
CCDEPMODE = @CCDEPMODE@
CFLAGS = @CFLAGS@
@@ -121,55 +190,59 @@ CHANGELOG_CMD = @CHANGELOG_CMD@
CPP = @CPP@
CPPFLAGS = @CPPFLAGS@
CWARNFLAGS = @CWARNFLAGS@
-CXX = @CXX@
-CXXCPP = @CXXCPP@
-CXXDEPMODE = @CXXDEPMODE@
-CXXFLAGS = @CXXFLAGS@
CYGPATH_W = @CYGPATH_W@
DEFS = @DEFS@
DEPDIR = @DEPDIR@
+DLLTOOL = @DLLTOOL@
DRIVER_MAN_DIR = @DRIVER_MAN_DIR@
DRIVER_MAN_SUFFIX = @DRIVER_MAN_SUFFIX@
DRIVER_NAME = @DRIVER_NAME@
DSYMUTIL = @DSYMUTIL@
-ECHO = @ECHO@
+DUMPBIN = @DUMPBIN@
ECHO_C = @ECHO_C@
ECHO_N = @ECHO_N@
ECHO_T = @ECHO_T@
EGREP = @EGREP@
EXEEXT = @EXEEXT@
-F77 = @F77@
-FFLAGS = @FFLAGS@
+FGREP = @FGREP@
FILE_MAN_DIR = @FILE_MAN_DIR@
FILE_MAN_SUFFIX = @FILE_MAN_SUFFIX@
GREP = @GREP@
+INSTALL = @INSTALL@
INSTALL_CMD = @INSTALL_CMD@
INSTALL_DATA = @INSTALL_DATA@
INSTALL_PROGRAM = @INSTALL_PROGRAM@
INSTALL_SCRIPT = @INSTALL_SCRIPT@
INSTALL_STRIP_PROGRAM = @INSTALL_STRIP_PROGRAM@
+LD = @LD@
LDFLAGS = @LDFLAGS@
LIBOBJS = @LIBOBJS@
LIBS = @LIBS@
LIBTOOL = @LIBTOOL@
LIB_MAN_DIR = @LIB_MAN_DIR@
LIB_MAN_SUFFIX = @LIB_MAN_SUFFIX@
+LIPO = @LIPO@
LN_S = @LN_S@
LTLIBOBJS = @LTLIBOBJS@
MAINT = @MAINT@
-MAINTAINER_MODE_FALSE = @MAINTAINER_MODE_FALSE@
-MAINTAINER_MODE_TRUE = @MAINTAINER_MODE_TRUE@
MAKEINFO = @MAKEINFO@
+MANIFEST_TOOL = @MANIFEST_TOOL@
MAN_SUBSTS = @MAN_SUBSTS@
MISC_MAN_DIR = @MISC_MAN_DIR@
MISC_MAN_SUFFIX = @MISC_MAN_SUFFIX@
+MKDIR_P = @MKDIR_P@
+NM = @NM@
NMEDIT = @NMEDIT@
+OBJDUMP = @OBJDUMP@
OBJEXT = @OBJEXT@
+OTOOL = @OTOOL@
+OTOOL64 = @OTOOL64@
PACKAGE = @PACKAGE@
PACKAGE_BUGREPORT = @PACKAGE_BUGREPORT@
PACKAGE_NAME = @PACKAGE_NAME@
PACKAGE_STRING = @PACKAGE_STRING@
PACKAGE_TARNAME = @PACKAGE_TARNAME@
+PACKAGE_URL = @PACKAGE_URL@
PACKAGE_VERSION = @PACKAGE_VERSION@
PATH_SEPARATOR = @PATH_SEPARATOR@
PCIACCESS_CFLAGS = @PCIACCESS_CFLAGS@
@@ -179,20 +252,19 @@ RANLIB = @RANLIB@
SED = @SED@
SET_MAKE = @SET_MAKE@
SHELL = @SHELL@
+STRICT_CFLAGS = @STRICT_CFLAGS@
STRIP = @STRIP@
VERSION = @VERSION@
XORG_CFLAGS = @XORG_CFLAGS@
XORG_LIBS = @XORG_LIBS@
XORG_MAN_PAGE = @XORG_MAN_PAGE@
-XSERVER_LIBPCIACCESS_FALSE = @XSERVER_LIBPCIACCESS_FALSE@
-XSERVER_LIBPCIACCESS_TRUE = @XSERVER_LIBPCIACCESS_TRUE@
+abs_builddir = @abs_builddir@
+abs_srcdir = @abs_srcdir@
+abs_top_builddir = @abs_top_builddir@
+abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
ac_ct_CC = @ac_ct_CC@
-ac_ct_CXX = @ac_ct_CXX@
-ac_ct_F77 = @ac_ct_F77@
-am__fastdepCC_FALSE = @am__fastdepCC_FALSE@
-am__fastdepCC_TRUE = @am__fastdepCC_TRUE@
-am__fastdepCXX_FALSE = @am__fastdepCXX_FALSE@
-am__fastdepCXX_TRUE = @am__fastdepCXX_TRUE@
+ac_ct_DUMPBIN = @ac_ct_DUMPBIN@
am__include = @am__include@
am__leading_dot = @am__leading_dot@
am__quote = @am__quote@
@@ -204,6 +276,7 @@ build_alias = @build_alias@
build_cpu = @build_cpu@
build_os = @build_os@
build_vendor = @build_vendor@
+builddir = @builddir@
datadir = @datadir@
datarootdir = @datarootdir@
docdir = @docdir@
@@ -232,8 +305,12 @@ program_transform_name = @program_transform_name@
psdir = @psdir@
sbindir = @sbindir@
sharedstatedir = @sharedstatedir@
+srcdir = @srcdir@
sysconfdir = @sysconfdir@
target_alias = @target_alias@
+top_build_prefix = @top_build_prefix@
+top_builddir = @top_builddir@
+top_srcdir = @top_srcdir@
# this is obnoxious:
# -module lets us name the module exactly how we want
@@ -245,10 +322,9 @@ rendition_drv_la_LTLIBRARIES = rendition_drv.la
rendition_drv_la_LDFLAGS = -module -avoid-version
rendition_drv_ladir = @moduledir@/drivers
rendition_drv_la_SOURCES = \
- accel.h \
- accelX.c \
cmd2d.h \
commonregs.h \
+ compat-api.h \
cscode.h \
hwcursor.c \
hwcursor.h \
@@ -280,6 +356,8 @@ dist_driver_DATA = \
v20002d.uc
EXTRA_DIST = \
+ accel.h \
+ accelX.c \
README.uc \
vgafont-std.data \
vgafont-vrx.data \
@@ -293,14 +371,14 @@ $(srcdir)/Makefile.in: @MAINTAINER_MODE_TRUE@ $(srcdir)/Makefile.am $(am__confi
@for dep in $?; do \
case '$(am__configure_deps)' in \
*$$dep*) \
- cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh \
- && exit 0; \
+ ( cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh ) \
+ && { if test -f $@; then exit 0; else break; fi; }; \
exit 1;; \
esac; \
done; \
- echo ' cd $(top_srcdir) && $(AUTOMAKE) --foreign src/Makefile'; \
- cd $(top_srcdir) && \
- $(AUTOMAKE) --foreign src/Makefile
+ echo ' cd $(top_srcdir) && $(AUTOMAKE) --foreign src/Makefile'; \
+ $(am__cd) $(top_srcdir) && \
+ $(AUTOMAKE) --foreign src/Makefile
.PRECIOUS: Makefile
Makefile: $(srcdir)/Makefile.in $(top_builddir)/config.status
@case '$?' in \
@@ -318,35 +396,43 @@ $(top_srcdir)/configure: @MAINTAINER_MODE_TRUE@ $(am__configure_deps)
cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
$(ACLOCAL_M4): @MAINTAINER_MODE_TRUE@ $(am__aclocal_m4_deps)
cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
+$(am__aclocal_m4_deps):
install-rendition_drv_laLTLIBRARIES: $(rendition_drv_la_LTLIBRARIES)
@$(NORMAL_INSTALL)
- test -z "$(rendition_drv_ladir)" || $(mkdir_p) "$(DESTDIR)$(rendition_drv_ladir)"
- @list='$(rendition_drv_la_LTLIBRARIES)'; for p in $$list; do \
+ @list='$(rendition_drv_la_LTLIBRARIES)'; test -n "$(rendition_drv_ladir)" || list=; \
+ list2=; for p in $$list; do \
if test -f $$p; then \
- f=$(am__strip_dir) \
- echo " $(LIBTOOL) --mode=install $(rendition_drv_laLTLIBRARIES_INSTALL) $(INSTALL_STRIP_FLAG) '$$p' '$(DESTDIR)$(rendition_drv_ladir)/$$f'"; \
- $(LIBTOOL) --mode=install $(rendition_drv_laLTLIBRARIES_INSTALL) $(INSTALL_STRIP_FLAG) "$$p" "$(DESTDIR)$(rendition_drv_ladir)/$$f"; \
+ list2="$$list2 $$p"; \
else :; fi; \
- done
+ done; \
+ test -z "$$list2" || { \
+ echo " $(MKDIR_P) '$(DESTDIR)$(rendition_drv_ladir)'"; \
+ $(MKDIR_P) "$(DESTDIR)$(rendition_drv_ladir)" || exit 1; \
+ echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(rendition_drv_ladir)'"; \
+ $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(rendition_drv_ladir)"; \
+ }
uninstall-rendition_drv_laLTLIBRARIES:
@$(NORMAL_UNINSTALL)
- @set -x; list='$(rendition_drv_la_LTLIBRARIES)'; for p in $$list; do \
- p=$(am__strip_dir) \
- echo " $(LIBTOOL) --mode=uninstall rm -f '$(DESTDIR)$(rendition_drv_ladir)/$$p'"; \
- $(LIBTOOL) --mode=uninstall rm -f "$(DESTDIR)$(rendition_drv_ladir)/$$p"; \
+ @list='$(rendition_drv_la_LTLIBRARIES)'; test -n "$(rendition_drv_ladir)" || list=; \
+ for p in $$list; do \
+ $(am__strip_dir) \
+ echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f '$(DESTDIR)$(rendition_drv_ladir)/$$f'"; \
+ $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f "$(DESTDIR)$(rendition_drv_ladir)/$$f"; \
done
clean-rendition_drv_laLTLIBRARIES:
-test -z "$(rendition_drv_la_LTLIBRARIES)" || rm -f $(rendition_drv_la_LTLIBRARIES)
- @list='$(rendition_drv_la_LTLIBRARIES)'; for p in $$list; do \
- dir="`echo $$p | sed -e 's|/[^/]*$$||'`"; \
- test "$$dir" != "$$p" || dir=.; \
- echo "rm -f \"$${dir}/so_locations\""; \
- rm -f "$${dir}/so_locations"; \
- done
-rendition_drv.la: $(rendition_drv_la_OBJECTS) $(rendition_drv_la_DEPENDENCIES)
- $(LINK) -rpath $(rendition_drv_ladir) $(rendition_drv_la_LDFLAGS) $(rendition_drv_la_OBJECTS) $(rendition_drv_la_LIBADD) $(LIBS)
+ @list='$(rendition_drv_la_LTLIBRARIES)'; \
+ locs=`for p in $$list; do echo $$p; done | \
+ sed 's|^[^/]*$$|.|; s|/[^/]*$$||; s|$$|/so_locations|' | \
+ sort -u`; \
+ test -z "$$locs" || { \
+ echo rm -f $${locs}; \
+ rm -f $${locs}; \
+ }
+rendition_drv.la: $(rendition_drv_la_OBJECTS) $(rendition_drv_la_DEPENDENCIES) $(EXTRA_rendition_drv_la_DEPENDENCIES)
+ $(AM_V_CCLD)$(rendition_drv_la_LINK) -rpath $(rendition_drv_ladir) $(rendition_drv_la_OBJECTS) $(rendition_drv_la_LIBADD) $(LIBS)
mostlyclean-compile:
-rm -f *.$(OBJEXT)
@@ -354,7 +440,6 @@ mostlyclean-compile:
distclean-compile:
-rm -f *.tab.c
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/accelX.Plo@am__quote@
@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/hwcursor.Plo@am__quote@
@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rendition.Plo@am__quote@
@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rendition_shadow.Plo@am__quote@
@@ -366,125 +451,146 @@ distclean-compile:
@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/vramdac.Plo@am__quote@
.c.o:
-@am__fastdepCC_TRUE@ if $(COMPILE) -MT $@ -MD -MP -MF "$(DEPDIR)/$*.Tpo" -c -o $@ $<; \
-@am__fastdepCC_TRUE@ then mv -f "$(DEPDIR)/$*.Tpo" "$(DEPDIR)/$*.Po"; else rm -f "$(DEPDIR)/$*.Tpo"; exit 1; fi
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@am__fastdepCC_TRUE@ $(AM_V_CC)$(COMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCC_TRUE@ $(AM_V_at)$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ $(AM_V_CC)source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(COMPILE) -c $<
+@am__fastdepCC_FALSE@ $(AM_V_CC@am__nodep@)$(COMPILE) -c $<
.c.obj:
-@am__fastdepCC_TRUE@ if $(COMPILE) -MT $@ -MD -MP -MF "$(DEPDIR)/$*.Tpo" -c -o $@ `$(CYGPATH_W) '$<'`; \
-@am__fastdepCC_TRUE@ then mv -f "$(DEPDIR)/$*.Tpo" "$(DEPDIR)/$*.Po"; else rm -f "$(DEPDIR)/$*.Tpo"; exit 1; fi
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
+@am__fastdepCC_TRUE@ $(AM_V_CC)$(COMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ `$(CYGPATH_W) '$<'`
+@am__fastdepCC_TRUE@ $(AM_V_at)$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ $(AM_V_CC)source='$<' object='$@' libtool=no @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(COMPILE) -c `$(CYGPATH_W) '$<'`
+@am__fastdepCC_FALSE@ $(AM_V_CC@am__nodep@)$(COMPILE) -c `$(CYGPATH_W) '$<'`
.c.lo:
-@am__fastdepCC_TRUE@ if $(LTCOMPILE) -MT $@ -MD -MP -MF "$(DEPDIR)/$*.Tpo" -c -o $@ $<; \
-@am__fastdepCC_TRUE@ then mv -f "$(DEPDIR)/$*.Tpo" "$(DEPDIR)/$*.Plo"; else rm -f "$(DEPDIR)/$*.Tpo"; exit 1; fi
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
+@am__fastdepCC_TRUE@ $(AM_V_CC)$(LTCOMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
+@am__fastdepCC_TRUE@ $(AM_V_at)$(am__mv) $(DEPDIR)/$*.Tpo $(DEPDIR)/$*.Plo
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ $(AM_V_CC)source='$<' object='$@' libtool=yes @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(LTCOMPILE) -c -o $@ $<
+@am__fastdepCC_FALSE@ $(AM_V_CC@am__nodep@)$(LTCOMPILE) -c -o $@ $<
mostlyclean-libtool:
-rm -f *.lo
clean-libtool:
-rm -rf .libs _libs
-
-distclean-libtool:
- -rm -f libtool
-uninstall-info-am:
install-dist_driverDATA: $(dist_driver_DATA)
@$(NORMAL_INSTALL)
- test -z "$(driverdir)" || $(mkdir_p) "$(DESTDIR)$(driverdir)"
- @list='$(dist_driver_DATA)'; for p in $$list; do \
+ @list='$(dist_driver_DATA)'; test -n "$(driverdir)" || list=; \
+ if test -n "$$list"; then \
+ echo " $(MKDIR_P) '$(DESTDIR)$(driverdir)'"; \
+ $(MKDIR_P) "$(DESTDIR)$(driverdir)" || exit 1; \
+ fi; \
+ for p in $$list; do \
if test -f "$$p"; then d=; else d="$(srcdir)/"; fi; \
- f=$(am__strip_dir) \
- echo " $(dist_driverDATA_INSTALL) '$$d$$p' '$(DESTDIR)$(driverdir)/$$f'"; \
- $(dist_driverDATA_INSTALL) "$$d$$p" "$(DESTDIR)$(driverdir)/$$f"; \
+ echo "$$d$$p"; \
+ done | $(am__base_list) | \
+ while read files; do \
+ echo " $(INSTALL_DATA) $$files '$(DESTDIR)$(driverdir)'"; \
+ $(INSTALL_DATA) $$files "$(DESTDIR)$(driverdir)" || exit $$?; \
done
uninstall-dist_driverDATA:
@$(NORMAL_UNINSTALL)
- @list='$(dist_driver_DATA)'; for p in $$list; do \
- f=$(am__strip_dir) \
- echo " rm -f '$(DESTDIR)$(driverdir)/$$f'"; \
- rm -f "$(DESTDIR)$(driverdir)/$$f"; \
- done
+ @list='$(dist_driver_DATA)'; test -n "$(driverdir)" || list=; \
+ files=`for p in $$list; do echo $$p; done | sed -e 's|^.*/||'`; \
+ dir='$(DESTDIR)$(driverdir)'; $(am__uninstall_files_from_dir)
ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
unique=`for i in $$list; do \
if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
done | \
- $(AWK) ' { files[$$0] = 1; } \
- END { for (i in files) print i; }'`; \
+ $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+ END { if (nonempty) { for (i in files) print i; }; }'`; \
mkid -fID $$unique
tags: TAGS
TAGS: $(HEADERS) $(SOURCES) $(TAGS_DEPENDENCIES) \
$(TAGS_FILES) $(LISP)
- tags=; \
+ set x; \
here=`pwd`; \
list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
unique=`for i in $$list; do \
if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
done | \
- $(AWK) ' { files[$$0] = 1; } \
- END { for (i in files) print i; }'`; \
- if test -z "$(ETAGS_ARGS)$$tags$$unique"; then :; else \
+ $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+ END { if (nonempty) { for (i in files) print i; }; }'`; \
+ shift; \
+ if test -z "$(ETAGS_ARGS)$$*$$unique"; then :; else \
test -n "$$unique" || unique=$$empty_fix; \
- $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
- $$tags $$unique; \
+ if test $$# -gt 0; then \
+ $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+ "$$@" $$unique; \
+ else \
+ $(ETAGS) $(ETAGSFLAGS) $(AM_ETAGSFLAGS) $(ETAGS_ARGS) \
+ $$unique; \
+ fi; \
fi
ctags: CTAGS
CTAGS: $(HEADERS) $(SOURCES) $(TAGS_DEPENDENCIES) \
$(TAGS_FILES) $(LISP)
- tags=; \
- here=`pwd`; \
list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
unique=`for i in $$list; do \
if test -f "$$i"; then echo $$i; else echo $(srcdir)/$$i; fi; \
done | \
- $(AWK) ' { files[$$0] = 1; } \
- END { for (i in files) print i; }'`; \
- test -z "$(CTAGS_ARGS)$$tags$$unique" \
+ $(AWK) '{ files[$$0] = 1; nonempty = 1; } \
+ END { if (nonempty) { for (i in files) print i; }; }'`; \
+ test -z "$(CTAGS_ARGS)$$unique" \
|| $(CTAGS) $(CTAGSFLAGS) $(AM_CTAGSFLAGS) $(CTAGS_ARGS) \
- $$tags $$unique
+ $$unique
GTAGS:
here=`$(am__cd) $(top_builddir) && pwd` \
- && cd $(top_srcdir) \
- && gtags -i $(GTAGS_ARGS) $$here
+ && $(am__cd) $(top_srcdir) \
+ && gtags -i $(GTAGS_ARGS) "$$here"
+
+cscopelist: $(HEADERS) $(SOURCES) $(LISP)
+ list='$(SOURCES) $(HEADERS) $(LISP)'; \
+ case "$(srcdir)" in \
+ [\\/]* | ?:[\\/]*) sdir="$(srcdir)" ;; \
+ *) sdir=$(subdir)/$(srcdir) ;; \
+ esac; \
+ for i in $$list; do \
+ if test -f "$$i"; then \
+ echo "$(subdir)/$$i"; \
+ else \
+ echo "$$sdir/$$i"; \
+ fi; \
+ done >> $(top_builddir)/cscope.files
distclean-tags:
-rm -f TAGS ID GTAGS GRTAGS GSYMS GPATH tags
distdir: $(DISTFILES)
- @srcdirstrip=`echo "$(srcdir)" | sed 's|.|.|g'`; \
- topsrcdirstrip=`echo "$(top_srcdir)" | sed 's|.|.|g'`; \
- list='$(DISTFILES)'; for file in $$list; do \
- case $$file in \
- $(srcdir)/*) file=`echo "$$file" | sed "s|^$$srcdirstrip/||"`;; \
- $(top_srcdir)/*) file=`echo "$$file" | sed "s|^$$topsrcdirstrip/|$(top_builddir)/|"`;; \
- esac; \
+ @srcdirstrip=`echo "$(srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+ topsrcdirstrip=`echo "$(top_srcdir)" | sed 's/[].[^$$\\*]/\\\\&/g'`; \
+ list='$(DISTFILES)'; \
+ dist_files=`for file in $$list; do echo $$file; done | \
+ sed -e "s|^$$srcdirstrip/||;t" \
+ -e "s|^$$topsrcdirstrip/|$(top_builddir)/|;t"`; \
+ case $$dist_files in \
+ */*) $(MKDIR_P) `echo "$$dist_files" | \
+ sed '/\//!d;s|^|$(distdir)/|;s,/[^/]*$$,,' | \
+ sort -u` ;; \
+ esac; \
+ for file in $$dist_files; do \
if test -f $$file || test -d $$file; then d=.; else d=$(srcdir); fi; \
- dir=`echo "$$file" | sed -e 's,/[^/]*$$,,'`; \
- if test "$$dir" != "$$file" && test "$$dir" != "."; then \
- dir="/$$dir"; \
- $(mkdir_p) "$(distdir)$$dir"; \
- else \
- dir=''; \
- fi; \
if test -d $$d/$$file; then \
+ dir=`echo "/$$file" | sed -e 's,/[^/]*$$,,'`; \
+ if test -d "$(distdir)/$$file"; then \
+ find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
+ fi; \
if test -d $(srcdir)/$$file && test $$d != $(srcdir); then \
- cp -pR $(srcdir)/$$file $(distdir)$$dir || exit 1; \
+ cp -fpR $(srcdir)/$$file "$(distdir)$$dir" || exit 1; \
+ find "$(distdir)/$$file" -type d ! -perm -700 -exec chmod u+rwx {} \;; \
fi; \
- cp -pR $$d/$$file $(distdir)$$dir || exit 1; \
+ cp -fpR $$d/$$file "$(distdir)$$dir" || exit 1; \
else \
- test -f $(distdir)/$$file \
- || cp -p $$d/$$file $(distdir)/$$file \
+ test -f "$(distdir)/$$file" \
+ || cp -p $$d/$$file "$(distdir)/$$file" \
|| exit 1; \
fi; \
done
@@ -493,7 +599,7 @@ check: check-am
all-am: Makefile $(LTLIBRARIES) $(DATA)
installdirs:
for dir in "$(DESTDIR)$(rendition_drv_ladir)" "$(DESTDIR)$(driverdir)"; do \
- test -z "$$dir" || $(mkdir_p) "$$dir"; \
+ test -z "$$dir" || $(MKDIR_P) "$$dir"; \
done
install: install-am
install-exec: install-exec-am
@@ -505,16 +611,22 @@ install-am: all-am
installcheck: installcheck-am
install-strip:
- $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
- install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
- `test -z '$(STRIP)' || \
- echo "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'"` install
+ if test -z '$(STRIP)'; then \
+ $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+ install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+ install; \
+ else \
+ $(MAKE) $(AM_MAKEFLAGS) INSTALL_PROGRAM="$(INSTALL_STRIP_PROGRAM)" \
+ install_sh_PROGRAM="$(INSTALL_STRIP_PROGRAM)" INSTALL_STRIP_FLAG=-s \
+ "INSTALL_PROGRAM_ENV=STRIPPROG='$(STRIP)'" install; \
+ fi
mostlyclean-generic:
clean-generic:
distclean-generic:
-test -z "$(CONFIG_CLEAN_FILES)" || rm -f $(CONFIG_CLEAN_FILES)
+ -test . = "$(srcdir)" || test -z "$(CONFIG_CLEAN_VPATH_FILES)" || rm -f $(CONFIG_CLEAN_VPATH_FILES)
maintainer-clean-generic:
@echo "This command is intended for maintainers to use"
@@ -528,7 +640,7 @@ distclean: distclean-am
-rm -rf ./$(DEPDIR)
-rm -f Makefile
distclean-am: clean-am distclean-compile distclean-generic \
- distclean-libtool distclean-tags
+ distclean-tags
dvi: dvi-am
@@ -536,6 +648,8 @@ dvi-am:
html: html-am
+html-am:
+
info: info-am
info-am:
@@ -543,12 +657,30 @@ info-am:
install-data-am: install-dist_driverDATA \
install-rendition_drv_laLTLIBRARIES
+install-dvi: install-dvi-am
+
+install-dvi-am:
+
install-exec-am:
+install-html: install-html-am
+
+install-html-am:
+
install-info: install-info-am
+install-info-am:
+
install-man:
+install-pdf: install-pdf-am
+
+install-pdf-am:
+
+install-ps: install-ps-am
+
+install-ps-am:
+
installcheck-am:
maintainer-clean: maintainer-clean-am
@@ -569,22 +701,27 @@ ps: ps-am
ps-am:
-uninstall-am: uninstall-dist_driverDATA uninstall-info-am \
+uninstall-am: uninstall-dist_driverDATA \
uninstall-rendition_drv_laLTLIBRARIES
+.MAKE: install-am install-strip
+
.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
- clean-libtool clean-rendition_drv_laLTLIBRARIES ctags \
- distclean distclean-compile distclean-generic \
+ clean-libtool clean-rendition_drv_laLTLIBRARIES cscopelist \
+ ctags distclean distclean-compile distclean-generic \
distclean-libtool distclean-tags distdir dvi dvi-am html \
html-am info info-am install install-am install-data \
- install-data-am install-dist_driverDATA install-exec \
- install-exec-am install-info install-info-am install-man \
+ install-data-am install-dist_driverDATA install-dvi \
+ install-dvi-am install-exec install-exec-am install-html \
+ install-html-am install-info install-info-am install-man \
+ install-pdf install-pdf-am install-ps install-ps-am \
install-rendition_drv_laLTLIBRARIES install-strip installcheck \
installcheck-am installdirs maintainer-clean \
maintainer-clean-generic mostlyclean mostlyclean-compile \
mostlyclean-generic mostlyclean-libtool pdf pdf-am ps ps-am \
tags uninstall uninstall-am uninstall-dist_driverDATA \
- uninstall-info-am uninstall-rendition_drv_laLTLIBRARIES
+ uninstall-rendition_drv_laLTLIBRARIES
+
# Tell versions [3.59,3.63) of GNU make to not export all variables.
# Otherwise a system limit (for SysV at least) may be exceeded.
diff --git a/driver/xf86-video-rendition/src/accelX.c b/driver/xf86-video-rendition/src/accelX.c
index a499c5669..bd237b3da 100644
--- a/driver/xf86-video-rendition/src/accelX.c
+++ b/driver/xf86-video-rendition/src/accelX.c
@@ -133,7 +133,7 @@ RENDITIONAccelPreInit(ScrnInfoPtr pScreenInfo)
void
RENDITIONAccelXAAInit(ScreenPtr pScreen)
{
- ScrnInfoPtr pScreenInfo = xf86Screens[pScreen->myNum];
+ ScrnInfoPtr pScreenInfo = xf86ScreenToScrn(pScreen);
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
XAAInfoRecPtr pXAAinfo;
@@ -289,7 +289,7 @@ int
RENDITIONInitUcode(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob = pRendition->board.io_base;
+ unsigned long iob = pRendition->board.io_base;
if (0 == verite_getstride(pScreenInfo, NULL,
&pRendition->board.mode.stride0,
@@ -367,7 +367,7 @@ void
RENDITIONRestoreUcode(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob = pRendition->board.io_base;
+ unsigned long iob = pRendition->board.io_base;
vu8 memend;
@@ -410,7 +410,7 @@ void
RENDITIONSaveUcode(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob = pRendition->board.io_base;
+ unsigned long iob = pRendition->board.io_base;
vu8 memend;
#ifdef DEBUG
@@ -445,7 +445,7 @@ void
RENDITIONSyncV1000(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob = pRendition->board.io_base;
+ unsigned long iob = pRendition->board.io_base;
int c;
@@ -555,7 +555,7 @@ RENDITIONSubsequentScreenToScreenCopy(ScrnInfoPtr pScreenInfo,
int w, int h)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob = pRendition->board.io_base;
+ unsigned long iob = pRendition->board.io_base;
#ifdef DEBUG
@@ -607,7 +607,7 @@ RENDITIONSubsequentSolidFillRect(ScrnInfoPtr pScreenInfo,
int x, int y, int w, int h)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob = pRendition->board.io_base;
+ unsigned long iob = pRendition->board.io_base;
#ifdef DEBUG
@@ -639,7 +639,7 @@ RENDITIONSubsequentTwoPointLine(ScrnInfoPtr pScreenInfo,
int bias)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob = pRendition->board.io_base;
+ unsigned long iob = pRendition->board.io_base;
#ifdef DEBUG
diff --git a/driver/xf86-video-rendition/src/compat-api.h b/driver/xf86-video-rendition/src/compat-api.h
new file mode 100644
index 000000000..e4f03d20f
--- /dev/null
+++ b/driver/xf86-video-rendition/src/compat-api.h
@@ -0,0 +1,99 @@
+/*
+ * Copyright 2012 Red Hat, Inc.
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice (including the next
+ * paragraph) shall be included in all copies or substantial portions of the
+ * Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+ * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
+ *
+ * Author: Dave Airlie <airlied@redhat.com>
+ */
+
+/* this file provides API compat between server post 1.13 and pre it,
+ it should be reused inside as many drivers as possible */
+#ifndef COMPAT_API_H
+#define COMPAT_API_H
+
+#ifndef GLYPH_HAS_GLYPH_PICTURE_ACCESSOR
+#define GetGlyphPicture(g, s) GlyphPicture((g))[(s)->myNum]
+#define SetGlyphPicture(g, s, p) GlyphPicture((g))[(s)->myNum] = p
+#endif
+
+#ifndef XF86_HAS_SCRN_CONV
+#define xf86ScreenToScrn(s) xf86Screens[(s)->myNum]
+#define xf86ScrnToScreen(s) screenInfo.screens[(s)->scrnIndex]
+#endif
+
+#ifndef XF86_SCRN_INTERFACE
+
+#define SCRN_ARG_TYPE int
+#define SCRN_INFO_PTR(arg1) ScrnInfoPtr pScreenInfo = xf86Screens[(arg1)]
+
+#define SCREEN_ARG_TYPE int
+#define SCREEN_PTR(arg1) ScreenPtr pScreen = screenInfo.screens[(arg1)]
+
+#define SCREEN_INIT_ARGS_DECL int i, ScreenPtr pScreen, int argc, char **argv
+
+#define BLOCKHANDLER_ARGS_DECL int arg, pointer blockData, pointer pTimeout, pointer pReadmask
+#define BLOCKHANDLER_ARGS arg, blockData, pTimeout, pReadmask
+
+#define CLOSE_SCREEN_ARGS_DECL int scrnIndex, ScreenPtr pScreen
+#define CLOSE_SCREEN_ARGS scrnIndex, pScreen
+
+#define ADJUST_FRAME_ARGS_DECL int arg, int x, int y, int flags
+#define ADJUST_FRAME_ARGS(arg, x, y) (arg)->scrnIndex, x, y, 0
+
+#define SWITCH_MODE_ARGS_DECL int arg, DisplayModePtr mode, int flags
+#define SWITCH_MODE_ARGS(arg, m) (arg)->scrnIndex, m, 0
+
+#define FREE_SCREEN_ARGS_DECL int arg, int flags
+
+#define VT_FUNC_ARGS_DECL int arg, int flags
+#define VT_FUNC_ARGS pScreenInfo->scrnIndex, 0
+
+#define XF86_SCRN_ARG(x) ((x)->scrnIndex)
+#else
+#define SCRN_ARG_TYPE ScrnInfoPtr
+#define SCRN_INFO_PTR(arg1) ScrnInfoPtr pScreenInfo = (arg1)
+
+#define SCREEN_ARG_TYPE ScreenPtr
+#define SCREEN_PTR(arg1) ScreenPtr pScreen = (arg1)
+
+#define SCREEN_INIT_ARGS_DECL ScreenPtr pScreen, int argc, char **argv
+
+#define BLOCKHANDLER_ARGS_DECL ScreenPtr arg, pointer pTimeout, pointer pReadmask
+#define BLOCKHANDLER_ARGS arg, pTimeout, pReadmask
+
+#define CLOSE_SCREEN_ARGS_DECL ScreenPtr pScreen
+#define CLOSE_SCREEN_ARGS pScreen
+
+#define ADJUST_FRAME_ARGS_DECL ScrnInfoPtr arg, int x, int y
+#define ADJUST_FRAME_ARGS(arg, x, y) arg, x, y
+
+#define SWITCH_MODE_ARGS_DECL ScrnInfoPtr arg, DisplayModePtr mode
+#define SWITCH_MODE_ARGS(arg, m) arg, m
+
+#define FREE_SCREEN_ARGS_DECL ScrnInfoPtr arg
+
+#define VT_FUNC_ARGS_DECL ScrnInfoPtr arg
+#define VT_FUNC_ARGS pScreenInfo
+
+#define XF86_SCRN_ARG(x) (x)
+
+#endif
+
+#endif
diff --git a/driver/xf86-video-rendition/src/hwcursor.c b/driver/xf86-video-rendition/src/hwcursor.c
index c3b5ee88e..609417ae5 100644
--- a/driver/xf86-video-rendition/src/hwcursor.c
+++ b/driver/xf86-video-rendition/src/hwcursor.c
@@ -75,9 +75,9 @@ RenditionHWCursorRelease (ScrnInfoPtr pScreenInfo)
Bool
-RenditionHWCursorInit(int scrnIndex, ScreenPtr pScreen)
+RenditionHWCursorInit(ScreenPtr pScreen)
{
- ScrnInfoPtr pScreenInfo = xf86Screens[scrnIndex];
+ ScrnInfoPtr pScreenInfo = xf86ScreenToScrn(pScreen);
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
xf86CursorInfoPtr infoPtr;
diff --git a/driver/xf86-video-rendition/src/hwcursor.h b/driver/xf86-video-rendition/src/hwcursor.h
index e0d742bd5..cfe24d305 100644
--- a/driver/xf86-video-rendition/src/hwcursor.h
+++ b/driver/xf86-video-rendition/src/hwcursor.h
@@ -10,7 +10,7 @@
*/
void RenditionHWCursorPreInit(ScrnInfoPtr pScreenInfo);
-Bool RenditionHWCursorInit(int scrnIndex, ScreenPtr pScreen);
+Bool RenditionHWCursorInit(ScreenPtr pScreen);
void RenditionHWCursorRelease (ScrnInfoPtr pScreenInfo);
#define HC_SIZE (64*64*2)/8 /* 1024 */
diff --git a/driver/xf86-video-rendition/src/rendition.c b/driver/xf86-video-rendition/src/rendition.c
index 7a9e18beb..7c74f76be 100644
--- a/driver/xf86-video-rendition/src/rendition.c
+++ b/driver/xf86-video-rendition/src/rendition.c
@@ -38,14 +38,6 @@
#endif
/*
- * Activate acceleration code or not.
- *
- * WARNING BUGGY !!!
- * Yes, you activate it on your own risk.
- */
-#define USE_ACCEL 0
-
-/*
* includes
*/
@@ -58,7 +50,6 @@
#include "vtypes.h"
#include "vboard.h"
#include "vmodes.h"
-#include "accel.h"
#include "vramdac.h"
#include "rendition_shadow.h"
#include "vbe.h"
@@ -115,14 +106,14 @@ static Bool renditionPciProbe(DriverPtr drv, int entity_num,
static Bool renditionProbe(DriverPtr, int);
#endif
static Bool renditionPreInit(ScrnInfoPtr, int);
-static Bool renditionScreenInit(int, ScreenPtr, int, char **);
-static Bool renditionSwitchMode(int, DisplayModePtr, int);
-static void renditionAdjustFrame(int, int, int, int);
-static Bool renditionEnterVT(int, int);
-static void renditionLeaveVT(int, int);
-static void renditionFreeScreen(int, int);
-
-static ModeStatus renditionValidMode(int, DisplayModePtr, Bool, int);
+static Bool renditionScreenInit(SCREEN_INIT_ARGS_DECL);
+static Bool renditionSwitchMode(SWITCH_MODE_ARGS_DECL);
+static void renditionAdjustFrame(ADJUST_FRAME_ARGS_DECL);
+static Bool renditionEnterVT(VT_FUNC_ARGS_DECL);
+static void renditionLeaveVT(VT_FUNC_ARGS_DECL);
+static void renditionFreeScreen(FREE_SCREEN_ARGS_DECL);
+
+static ModeStatus renditionValidMode(SCRN_ARG_TYPE, DisplayModePtr, Bool, int);
static Bool renditionMapMem(ScrnInfoPtr pScreenInfo);
static Bool renditionUnmapMem(ScrnInfoPtr pScreenInfo);
#if 0
@@ -330,7 +321,7 @@ renditionProbe(DriverPtr drv, int flags)
renditionChipsets, renditionPCIchipsets,
devSections, numDevSections, drv, &usedChips);
- xfree(devSections);
+ free(devSections);
if (numUsed <= 0)
return FALSE;
@@ -359,7 +350,7 @@ renditionProbe(DriverPtr drv, int flags)
foundScreen=TRUE;
}
}
- xfree(usedChips);
+ free(usedChips);
}
return foundScreen;
}
@@ -400,7 +391,7 @@ renditionGetRec(ScrnInfoPtr pScreenInfo)
sleep(1);
#endif
if (!pScreenInfo->driverPrivate)
- pScreenInfo->driverPrivate=xcalloc(sizeof(renditionRec), 1);
+ pScreenInfo->driverPrivate=calloc(sizeof(renditionRec), 1);
/* perhaps some initialization? <ml> */
@@ -421,7 +412,7 @@ renditionFreeRec(ScrnInfoPtr pScreenInfo)
#endif
if (xf86LoaderCheckSymbol("vgaHWFreeHWRec"))
vgaHWFreeHWRec(pScreenInfo);
- xfree(pScreenInfo->driverPrivate);
+ free(pScreenInfo->driverPrivate);
pScreenInfo->driverPrivate=NULL;
#ifdef DEBUG
@@ -596,7 +587,7 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
/* collect all of the options flags and process them */
xf86CollectOptions(pScreenInfo, NULL);
- if (!(pRendition->Options = xalloc(sizeof(renditionOptions))))
+ if (!(pRendition->Options = malloc(sizeof(renditionOptions))))
return FALSE;
memcpy(pRendition->Options, renditionOptions, sizeof(renditionOptions));
xf86ProcessOptions(pScreenInfo->scrnIndex, pScreenInfo->options,
@@ -660,10 +651,14 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
pvgaHW = VGAHWPTR(pScreenInfo);
pvgaHW->MapSize = 0x00010000; /* Standard 64kB VGA window */
+ vgaHWSetStdFuncs(pvgaHW);
vgaHWGetIOBase(pvgaHW); /* Get VGA I/O base */
- pRendition->board.accel=0;
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 12
pRendition->board.vgaio_base = pvgaHW->PIOOffset;
+#else
+ pRendition->board.vgaio_base = 0;
+#endif
pRendition->board.io_base = pRendition->board.vgaio_base
#ifdef XSERVER_LIBPCIACCESS
+ pRendition->PciInfo->regions[1].base_addr;
@@ -864,31 +859,6 @@ renditionPreInit(ScrnInfoPtr pScreenInfo, int flags)
xf86DrvMsg(pScreenInfo->scrnIndex, X_CONFIG,
"Software cursor selected\n");
- /* Unmapping delayed until after micrcode loading */
- /****************************************/
- /* Reserve memory and load the microcode */
- /****************************************/
-#if USE_ACCEL
- if (!xf86ReturnOptValBool(pRendition->Options, OPTION_NOACCEL,0) &&
- !pRendition->board.shadowfb) {
- /* Load XAA if needed */
- if (xf86LoadSubModule(pScreenInfo, "xaa")) {
- renditionMapMem(pScreenInfo);
- RENDITIONAccelPreInit (pScreenInfo);
- renditionUnmapMem(pScreenInfo);
- pRendition->board.accel = TRUE;
- } else xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
- ("XAA module not found: "
- "Skipping acceleration\n"));
- }
- else
- xf86DrvMsg(pScreenInfo->scrnIndex, X_CONFIG,
- ("Skipping acceleration on users request\n"));
-#else
- xf86DrvMsg(pScreenInfo->scrnIndex, X_WARNING,
- ("Skipping acceleration\n"));
-#endif
-
#ifdef DEBUG
ErrorF("PreInit OK...!!!!\n");
sleep(2);
@@ -1052,9 +1022,9 @@ renditionLeaveGraphics(ScrnInfoPtr pScreenInfo)
/* Unravel the screen */
static Bool
-renditionCloseScreen(int scrnIndex, ScreenPtr pScreen)
+renditionCloseScreen(CLOSE_SCREEN_ARGS_DECL)
{
- ScrnInfoPtr pScreenInfo = xf86Screens[scrnIndex];
+ ScrnInfoPtr pScreenInfo = xf86ScreenToScrn(pScreen);
renditionPtr prenditionPriv=renditionGetRec(pScreenInfo);
Bool Closed = TRUE;
@@ -1066,9 +1036,6 @@ renditionCloseScreen(int scrnIndex, ScreenPtr pScreen)
if (prenditionPriv->board.hwcursor_used)
RenditionHWCursorRelease(pScreenInfo);
- if (prenditionPriv->board.accel)
- RENDITIONAccelNone(pScreenInfo);
-
if (pScreenInfo->vtSema)
renditionLeaveGraphics(pScreenInfo);
@@ -1077,7 +1044,7 @@ renditionCloseScreen(int scrnIndex, ScreenPtr pScreen)
if (prenditionPriv
&& (pScreen->CloseScreen = prenditionPriv->CloseScreen)) {
prenditionPriv->CloseScreen = NULL;
- Closed = (*pScreen->CloseScreen)(scrnIndex, pScreen);
+ Closed = (*pScreen->CloseScreen)(CLOSE_SCREEN_ARGS);
}
#ifdef DEBUG
@@ -1099,15 +1066,16 @@ renditionDPMSSet(ScrnInfoPtr pScreen, int mode, int flags)
}
static Bool
-renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
+renditionScreenInit(SCREEN_INIT_ARGS_DECL)
{
- ScrnInfoPtr pScreenInfo = xf86Screens[scrnIndex];
+ ScrnInfoPtr pScreenInfo = xf86ScreenToScrn(pScreen);
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
Bool Inited = FALSE;
unsigned char *FBBase;
VisualPtr visual;
vgaHWPtr pvgaHW;
int displayWidth,width,height;
+ int scrnIndex = pScreenInfo->scrnIndex;
#ifdef DEBUG
ErrorF("RENDITION: renditionScreenInit() called\n");
@@ -1142,8 +1110,8 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
/* blank the screen */
renditionSaveScreen(pScreen, SCREEN_SAVER_ON);
- (*pScreenInfo->AdjustFrame)(pScreenInfo->scrnIndex,
- pScreenInfo->frameX0, pScreenInfo->frameY0, 0);
+ (*pScreenInfo->AdjustFrame)(ADJUST_FRAME_ARGS(pScreenInfo,
+ pScreenInfo->frameX0, pScreenInfo->frameY0));
miClearVisualTypes();
@@ -1167,7 +1135,7 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
pRendition->board.shadowPitch
= BitmapBytePad(pScreenInfo->bitsPerPixel * width);
pRendition->board.shadowPtr
- = xalloc(pRendition->board.shadowPitch * height);
+ = malloc(pRendition->board.shadowPitch * height);
displayWidth = pRendition->board.shadowPitch
/ (pScreenInfo->bitsPerPixel >> 3);
FBBase = pRendition->board.shadowPtr;
@@ -1211,10 +1179,6 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
/* The actual setup of the driver-specific code */
/* has to be after fbScreenInit and before cursor init */
/*********************************************************/
-#if USE_ACCEL
- if (pRendition->board.accel)
- RENDITIONAccelXAAInit (pScreen);
-#endif
/* Initialise cursor functions */
xf86SetSilkenMouse(pScreen);
@@ -1223,7 +1187,7 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
if(!xf86ReturnOptValBool(pRendition->Options, OPTION_SW_CURSOR,0)&&
!pRendition->board.rotate){
/* Initialise HW cursor */
- if(!RenditionHWCursorInit(scrnIndex, pScreen)){
+ if(!RenditionHWCursorInit(pScreen)){
xf86DrvMsg(pScreenInfo->scrnIndex, X_ERROR,
"Hardware Cursor initalization failed!!\n");
}
@@ -1275,7 +1239,7 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
pScreen->SaveScreen = renditionSaveScreen;
if (!Inited)
- renditionCloseScreen(scrnIndex, pScreen);
+ renditionCloseScreen(CLOSE_SCREEN_ARGS);
if (serverGeneration == 1)
xf86ShowUnusedOptions(pScreenInfo->scrnIndex, pScreenInfo->options);
@@ -1288,19 +1252,20 @@ renditionScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
}
static Bool
-renditionSwitchMode(int scrnIndex, DisplayModePtr pMode, int flags)
+renditionSwitchMode(SWITCH_MODE_ARGS_DECL)
{
+ SCRN_INFO_PTR(arg);
#ifdef DEBUG
ErrorF("RENDITION: renditionSwitchMode() called\n");
#endif
- return renditionSetMode(xf86Screens[scrnIndex], pMode);
+ return renditionSetMode(pScreenInfo, mode);
}
static void
-renditionAdjustFrame(int scrnIndex, int x, int y, int flags)
+renditionAdjustFrame(ADJUST_FRAME_ARGS_DECL)
{
- ScrnInfoPtr pScreenInfo=xf86Screens[scrnIndex];
+ SCRN_INFO_PTR(arg);
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
int offset, virtualwidth, bitsPerPixel;
@@ -1322,9 +1287,9 @@ renditionAdjustFrame(int scrnIndex, int x, int y, int flags)
static Bool
-renditionEnterVT(int scrnIndex, int flags)
+renditionEnterVT(VT_FUNC_ARGS_DECL)
{
- ScrnInfoPtr pScreenInfo = xf86Screens[scrnIndex];
+ SCRN_INFO_PTR(arg);
vgaHWPtr pvgaHW = VGAHWPTR(pScreenInfo);
#ifdef DEBUG
@@ -1341,32 +1306,34 @@ renditionEnterVT(int scrnIndex, int flags)
if (!renditionSetMode(pScreenInfo, pScreenInfo->currentMode))
return FALSE;
- (*pScreenInfo->AdjustFrame)(pScreenInfo->scrnIndex,
- pScreenInfo->frameX0, pScreenInfo->frameY0, 0);
+ (*pScreenInfo->AdjustFrame)(ADJUST_FRAME_ARGS(pScreenInfo,
+ pScreenInfo->frameX0, pScreenInfo->frameY0));
return TRUE;
}
static void
-renditionLeaveVT(int scrnIndex, int flags)
+renditionLeaveVT(VT_FUNC_ARGS_DECL)
{
+ SCRN_INFO_PTR(arg);
#ifdef DEBUG
ErrorF("RENDITION: renditionLeaveVT() called\n");
#endif
- renditionLeaveGraphics(xf86Screens[scrnIndex]);
+ renditionLeaveGraphics(pScreenInfo);
}
static void
-renditionFreeScreen(int scrnIndex, int flags)
+renditionFreeScreen(FREE_SCREEN_ARGS_DECL)
{
- renditionFreeRec(xf86Screens[scrnIndex]);
+ SCRN_INFO_PTR(arg);
+ renditionFreeRec(pScreenInfo);
}
static ModeStatus
-renditionValidMode(int scrnIndex, DisplayModePtr pMode, Bool Verbose,
+renditionValidMode(SCRN_ARG_TYPE arg, DisplayModePtr pMode, Bool Verbose,
int flags)
{
if (pMode->Flags & V_INTERLACE)
@@ -1484,7 +1451,7 @@ static xf86MonPtr
renditionDDC (ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base;
+ unsigned long iob=pRendition->board.io_base;
vu32 temp;
xf86MonPtr MonInfo = NULL;
@@ -1517,7 +1484,7 @@ static unsigned int
renditionDDC1Read (ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base;
+ unsigned long iob=pRendition->board.io_base;
vu32 value = 0;
/* wait for Vsync */
diff --git a/driver/xf86-video-rendition/src/rendition.h b/driver/xf86-video-rendition/src/rendition.h
index 0ea5cca62..f7f13d4a3 100644
--- a/driver/xf86-video-rendition/src/rendition.h
+++ b/driver/xf86-video-rendition/src/rendition.h
@@ -53,8 +53,10 @@
#include "fb.h"
/* Drivers using the XAA interface ... */
+#ifdef HAVE_XAA_H
#include "xaa.h"
#include "xaalocal.h"
+#endif
#include "xf86fbman.h"
/* HW-cursor definitions */
@@ -65,5 +67,6 @@
#include "commonregs.h"
+#include "compat-api.h"
/* end of __RENDITION_H__ */
#endif
diff --git a/driver/xf86-video-rendition/src/rendition_shadow.c b/driver/xf86-video-rendition/src/rendition_shadow.c
index 5f7a5f5ba..b5e4ef6ee 100644
--- a/driver/xf86-video-rendition/src/rendition_shadow.c
+++ b/driver/xf86-video-rendition/src/rendition_shadow.c
@@ -48,9 +48,9 @@ renditionRefreshArea(ScrnInfoPtr pScreenInfo, int num, BoxPtr pbox)
}
void
-renditionPointerMoved(int index, int x, int y)
+renditionPointerMoved(SCRN_ARG_TYPE arg, int x, int y)
{
- ScrnInfoPtr pScreenInfo = xf86Screens[index];
+ SCRN_INFO_PTR(arg);
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
int newX, newY;
@@ -62,7 +62,7 @@ renditionPointerMoved(int index, int x, int y)
newY = pScreenInfo->pScreen->width - x - 1;
}
- (*pRendition->board.PointerMoved)(index, newX, newY);
+ (*pRendition->board.PointerMoved)(arg, newX, newY);
}
void
diff --git a/driver/xf86-video-rendition/src/rendition_shadow.h b/driver/xf86-video-rendition/src/rendition_shadow.h
index 5d9634fee..d4527a8ba 100644
--- a/driver/xf86-video-rendition/src/rendition_shadow.h
+++ b/driver/xf86-video-rendition/src/rendition_shadow.h
@@ -12,7 +12,7 @@ void renditionRefreshArea8(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
void renditionRefreshArea16(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
void renditionRefreshArea24(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
void renditionRefreshArea32(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
-void renditionPointerMoved(int index, int x, int y);
+void renditionPointerMoved(SCRN_ARG_TYPE arg, int x, int y);
#endif
diff --git a/driver/xf86-video-rendition/src/vboard.c b/driver/xf86-video-rendition/src/vboard.c
index 49499e2e8..622715fee 100644
--- a/driver/xf86-video-rendition/src/vboard.c
+++ b/driver/xf86-video-rendition/src/vboard.c
@@ -38,7 +38,7 @@ verite_initboard(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base;
+ unsigned long iob=pRendition->board.io_base;
vu8 *vmb;
vu32 offset;
vu8 memendian;
@@ -207,7 +207,7 @@ void
verite_check_csucode(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base;
+ unsigned long iob=pRendition->board.io_base;
vu8 *vmb;
vu32 offset;
int c;
diff --git a/driver/xf86-video-rendition/src/vgafont-std.data b/driver/xf86-video-rendition/src/vgafont-std.data
index db63ea888..c47983ff3 100644
--- a/driver/xf86-video-rendition/src/vgafont-std.data
+++ b/driver/xf86-video-rendition/src/vgafont-std.data
@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/rendition/vgafont-std.data,v 1.3 1999/10/13 04:21:22 dawes Exp $ */
#ifndef __VGAFONT_STD__
#define __VGAFONT_STD__
diff --git a/driver/xf86-video-rendition/src/vgafont-vrx.data b/driver/xf86-video-rendition/src/vgafont-vrx.data
index ad3458218..23b59083e 100644
--- a/driver/xf86-video-rendition/src/vgafont-vrx.data
+++ b/driver/xf86-video-rendition/src/vgafont-vrx.data
@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/rendition/vgafont-vrx.data,v 1.3 1999/10/13 04:21:23 dawes Exp $ */
#ifndef __VGAFONT_VRX__
#define __VGAFONT_VRX__
diff --git a/driver/xf86-video-rendition/src/vgapalette.data b/driver/xf86-video-rendition/src/vgapalette.data
index 526760828..106028d9e 100644
--- a/driver/xf86-video-rendition/src/vgapalette.data
+++ b/driver/xf86-video-rendition/src/vgapalette.data
@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/rendition/vgapalette.data,v 1.3 1999/10/13 04:21:23 dawes Exp $ */
#ifndef __VGAPALETTE__
#define __VGAPALETTE__
diff --git a/driver/xf86-video-rendition/src/vloaduc.c b/driver/xf86-video-rendition/src/vloaduc.c
index 67bf901df..5c6aab012 100644
--- a/driver/xf86-video-rendition/src/vloaduc.c
+++ b/driver/xf86-video-rendition/src/vloaduc.c
@@ -103,7 +103,7 @@ verite_load_ucfile(ScrnInfoPtr pScreenInfo, char *file_name)
sz=SW16(ehdr.e_phentsize);
num=SW16(ehdr.e_phnum);
if (0!=sz && 0!=num) {
- orig_pphdr=pphdr=(Elf32_Phdr *)xalloc(sz*num);
+ orig_pphdr=pphdr=(Elf32_Phdr *)malloc(sz*num);
if (!pphdr) {
ErrorF("RENDITION: Cannot allocate global memory (1)\n");
close(fd);
@@ -125,7 +125,7 @@ verite_load_ucfile(ScrnInfoPtr pScreenInfo, char *file_name)
sz=SW16(ehdr.e_shentsize);
num=SW16(ehdr.e_shnum);
if (0!=sz && 0!=num) {
- orig_pshdr=pshdr=(Elf32_Shdr *)xalloc(sz*num);
+ orig_pshdr=pshdr=(Elf32_Shdr *)malloc(sz*num);
if (!pshdr) {
ErrorF("RENDITION: Cannot allocate global memory (2)\n");
close(fd);
@@ -148,7 +148,7 @@ verite_load_ucfile(ScrnInfoPtr pScreenInfo, char *file_name)
loadSegment2board(pScreenInfo, fd, pphdr);
pphdr=(Elf32_Phdr *)(((char *)pphdr)+sz);
} while (--num);
- xfree(orig_pphdr);
+ free(orig_pphdr);
}
else {
do {
@@ -158,7 +158,7 @@ verite_load_ucfile(ScrnInfoPtr pScreenInfo, char *file_name)
loadSection2board(pScreenInfo, fd, pshdr);
pshdr=(Elf32_Shdr *)(((char *)pshdr)+sz);
} while (--num) ;
- xfree(orig_pshdr);
+ free(orig_pshdr);
}
close(fd);
@@ -195,7 +195,7 @@ loadSegment2board(ScrnInfoPtr pScreenInfo, int fd, Elf32_Phdr *phdr)
return;
}
- data=(vu8 *)xalloc(size);
+ data=(vu8 *)malloc(size);
if (NULL == data){
ErrorF("RENDITION: GlobalAllocPtr couldn't allocate %lx bytes",
(unsigned long)size);
@@ -210,7 +210,7 @@ loadSegment2board(ScrnInfoPtr pScreenInfo, int fd, Elf32_Phdr *phdr)
mmve(pScreenInfo, size, data, physAddr);
- xfree(data);
+ free(data);
}
diff --git a/driver/xf86-video-rendition/src/vmodes.c b/driver/xf86-video-rendition/src/vmodes.c
index c0bd0df35..ba91d1afd 100644
--- a/driver/xf86-video-rendition/src/vmodes.c
+++ b/driver/xf86-video-rendition/src/vmodes.c
@@ -20,6 +20,7 @@
#include "v1kregs.h"
#include "v2kregs.h"
+#include <unistd.h>
#undef DEBUG
@@ -201,7 +202,7 @@ struct V1000ClocksStr {
* local function prototypes
*/
-static void set_PLL(IOADDRESS iob, vu32 value);
+static void set_PLL(unsigned long iob, vu32 value);
static double V1000CalcClock(double target, int *M, int *N, int *P);
static double V2200CalcClock(double target, int *m, int *n, int *p);
@@ -300,8 +301,8 @@ verite_setmode(ScrnInfoPtr pScreenInfo, struct verite_modeinfo_t *mode)
pRendition->board.mode.virtualwidth=pRendition->board.mode.screenwidth;
pRendition->board.init=1;
- (*pScreenInfo->AdjustFrame)(pScreenInfo->scrnIndex,
- pScreenInfo->frameX0, pScreenInfo->frameY0, 0);
+ (*pScreenInfo->AdjustFrame)(ADJUST_FRAME_ARGS(pScreenInfo,
+ pScreenInfo->frameX0, pScreenInfo->frameY0));
/* Need to fix up syncs */
@@ -509,13 +510,13 @@ verite_getstride(ScrnInfoPtr pScreenInfo, int *width,
*/
/*
- * void set_PLL(IOADDRESS iob, vu32 value)
+ * void set_PLL(unsigned long iob, vu32 value)
*
* Set PLL clock to desired frequency for the V1000.
*/
void
-set_PLL(IOADDRESS iob, vu32 value)
+set_PLL(unsigned long iob, vu32 value)
{
vu32 ulD;
int b;
diff --git a/driver/xf86-video-rendition/src/vos.h b/driver/xf86-video-rendition/src/vos.h
index 7b55f77cf..999c8709c 100644
--- a/driver/xf86-video-rendition/src/vos.h
+++ b/driver/xf86-video-rendition/src/vos.h
@@ -23,18 +23,18 @@
/*
* function prototypes
*/
-#define /*void*/ verite_out8(/*IOADDRESS*/ port, /*vu8*/ data) \
+#define /*void*/ verite_out8(/*unsigned long*/ port, /*vu8*/ data) \
outb(port, data)
-#define /*void*/ verite_out16(/*IOADDRESS*/ port, /*vu16*/ data) \
+#define /*void*/ verite_out16(/*unsigned long*/ port, /*vu16*/ data) \
outw(port, data)
-#define /*void*/ verite_out32(/*IOADDRESS*/ port, /*vu32*/ data) \
+#define /*void*/ verite_out32(/*unsigned long*/ port, /*vu32*/ data) \
outl(port, data)
-#define /*vu8*/ verite_in8(/*IOADDRESS*/ io_base) ((vu8)inb(io_base))
-#define /*vu16*/ verite_in16(/*IOADDRESS*/ io_base) ((vu16)inw(io_base))
-#define /*vu32*/ verite_in32(/*IOADDRESS*/ io_base) ((vu32)inl(io_base))
+#define /*vu8*/ verite_in8(/*unsigned long*/ io_base) ((vu8)inb(io_base))
+#define /*vu16*/ verite_in16(/*unsigned long*/ io_base) ((vu16)inw(io_base))
+#define /*vu32*/ verite_in32(/*unsigned long*/ io_base) ((vu32)inl(io_base))
/* memory accesses */
#define verite_read_memory32(base, offset) MMIO_IN32(base, offset)
diff --git a/driver/xf86-video-rendition/src/vtypes.h b/driver/xf86-video-rendition/src/vtypes.h
index 257870bdf..b221aa34b 100644
--- a/driver/xf86-video-rendition/src/vtypes.h
+++ b/driver/xf86-video-rendition/src/vtypes.h
@@ -123,7 +123,7 @@ struct verite_board_t {
vu16 chip;
/* */
- IOADDRESS io_base, vgaio_base;
+ unsigned long io_base, vgaio_base;
vu32 mmio_base;
vu32 vmmio_base;
vu32 mem_size;
@@ -132,9 +132,6 @@ struct verite_board_t {
Bool init;
/* */
- Bool accel;
-
- /* */
vu32 csucode_base;
vu32 ucode_base;
vu32 ucode_entry;
@@ -164,7 +161,7 @@ struct verite_board_t {
Bool shadowfb; /* Use ShadowFB ? */
vu8 *shadowPtr;
vu32 shadowPitch;
- void (*PointerMoved)(int index, int x, int y);
+ void (*PointerMoved)(SCRN_ARG_TYPE arg, int x, int y);
int rotate; /* Rotate clockwise or counterclockwise */
@@ -188,7 +185,9 @@ typedef struct _renditionRec
EntityInfoPtr pEnt; /* entity information */
CloseScreenProcPtr CloseScreen; /* wrap CloseScreen */
xf86CursorInfoPtr CursorInfoRec; /* Cursor data */
+#ifdef HAVE_XAA_H
XAAInfoRecPtr AccelInfoRec; /* Needed for XAA */
+#endif
OptionInfoPtr Options;
RenditionRegRec saveRegs;
} renditionRec, *renditionPtr;
diff --git a/driver/xf86-video-rendition/src/v1krisc.c b/driver/xf86-video-rendition/src/v1krisc.c
index 255426332..9b7b4e208 100644
--- a/driver/xf86-video-rendition/src/v1krisc.c
+++ b/driver/xf86-video-rendition/src/v1krisc.c
@@ -83,20 +83,20 @@
* local function prototypes
*/
-static void verite_iopoll(IOADDRESS port, vu32 data, vu32 mask);
-static void verite_iopoll8(IOADDRESS port, vu8 data, vu8 mask);
+static void verite_iopoll(unsigned long port, vu32 data, vu32 mask);
+static void verite_iopoll8(unsigned long port, vu8 data, vu8 mask);
-static vu32 readRF(IOADDRESS io_base, vu8 index);
-static void writeRF(IOADDRESS io_base, vu8 index, vu32 data);
+static vu32 readRF(unsigned long io_base, vu8 index);
+static void writeRF(unsigned long io_base, vu8 index, vu32 data);
-static vu32 risc_readmem(IOADDRESS io_base, vu32 addr, vu8 read_type);
-static void risc_writemem(IOADDRESS io_base, vu32 addr, vu32 data, vu8 write_type);
+static vu32 risc_readmem(unsigned long io_base, vu32 addr, vu8 read_type);
+static void risc_writemem(unsigned long io_base, vu32 addr, vu32 data, vu8 write_type);
#if 0
-static void risc_step(IOADDRESS io_base, vu32 count);
+static void risc_step(unsigned long io_base, vu32 count);
#endif
-static void risc_forcestep(IOADDRESS io_base, vu32 instruction);
-static void risc_continue(IOADDRESS io_base);
+static void risc_forcestep(unsigned long io_base, vu32 instruction);
+static void risc_continue(unsigned long io_base);
@@ -113,7 +113,7 @@ void
v1k_start(ScrnInfoPtr pScreenInfo, vu32 pc)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS io_base=pRendition->board.io_base;
+ unsigned long io_base=pRendition->board.io_base;
v1k_stop(pScreenInfo);
risc_forcestep(io_base, NOP_INSTR);
@@ -152,7 +152,7 @@ v1k_stop(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
vu8 debugreg, statusreg;
- IOADDRESS io_base=pRendition->board.io_base;
+ unsigned long io_base=pRendition->board.io_base;
vu16 STATUS = 0x4A; /* v2x00 io register offset */
int c;
@@ -207,7 +207,7 @@ v1k_flushicache(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
vu32 c, p1, p2;
- IOADDRESS io_base=pRendition->board.io_base;
+ unsigned long io_base=pRendition->board.io_base;
/* first flush store accumulation buffers so data is all in memory */
p1=risc_readmem(io_base, 0, READ_WORD);
@@ -255,7 +255,7 @@ void
v1k_softreset(ScrnInfoPtr pScreenInfo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS io_base=pRendition->board.io_base;
+ unsigned long io_base=pRendition->board.io_base;
verite_out8(io_base+DEBUGREG, SOFTRESET|HOLDRISC);
verite_out8(io_base+STATEINDEX, STATEINDEX_PC);
@@ -300,12 +300,12 @@ v1k_getriscprocs(verite_board_desc *boardDesc)
*/
/*
* static void verite_iopoll(IOADDRESS port, vu32 data, vu32 mask)
*
* Loop on IO read until expected data is read or VERITE_MAX_POLLS is reached.
*/
static void
-verite_iopoll(IOADDRESS port, vu32 data, vu32 mask)
+verite_iopoll(unsigned long port, vu32 data, vu32 mask)
{
vu32 c;
@@ -320,12 +320,12 @@ verite_iopoll(IOADDRESS port, vu32 data, vu32 mask)
/*
* static void verite_iopoll8(IOADDRESS port, vu8 data, vu8 mask)
*
* Loop on IO read until expected data is read or VERITE_MAX_POLLS is reached.
*/
static void
-verite_iopoll8(IOADDRESS port, vu8 data, vu8 mask)
+verite_iopoll8(unsigned long port, vu8 data, vu8 mask)
{
vu32 c;
@@ -340,12 +340,12 @@ verite_iopoll8(IOADDRESS port, vu8 data, vu8 mask)
/*
- * static vu32 readRF(IOADDRESS io_base, vu8 index)
+ * static vu32 readRF(unsigned long io_base, vu8 index)
*
* Reads data from register file.
*/
static vu32
-readRF(IOADDRESS io_base, vu8 index)
+readRF(unsigned long io_base, vu8 index)
{
vu32 data, instr;
vu8 debug, stateindex;
@@ -378,12 +378,12 @@ readRF(IOADDRESS io_base, vu8 index)
/*
* static void writeRF(IOADDRESS io_base, vu8 index, vu32 data)
*
* Set RF register, being careful on how to set regs below 64.
*/
static void
-writeRF(IOADDRESS io_base, vu8 index, vu32 data)
+writeRF(unsigned long io_base, vu8 index, vu32 data)
{
vu8 special=0;
@@ -417,12 +417,12 @@ writeRF(IOADDRESS io_base, vu8 index, vu32 data)
/*
- * static vu32 risc_readmem(IOADDRESS io_base, vu32 addr, vu8 read_type)
+ * static vu32 risc_readmem(unsigned long io_base, vu32 addr, vu8 read_type)
*
* NOTE: Assumes RISC is in hold mode.
*/
static vu32
-risc_readmem(IOADDRESS io_base, vu32 addr, vu8 read_type)
+risc_readmem(unsigned long io_base, vu32 addr, vu8 read_type)
{
vu32 data;
@@ -445,12 +445,12 @@ risc_readmem(IOADDRESS io_base, vu32 addr, vu8 read_type)
/*
* static vu32 risc_writemem(IOADDRESS io_base, vu32 addr, vu32 data, vu8 write_type)
*
* NOTE: Assumes RISC is in hold mode.
*/
static void
-risc_writemem(IOADDRESS io_base, vu32 addr, vu32 data, vu8 write_type)
+risc_writemem(unsigned long io_base, vu32 addr, vu32 data, vu8 write_type)
{
writeRF(io_base, RISC_RA, addr); /* point to memory */
writeRF(io_base, RISC_FP, data); /* set data */
@@ -466,12 +466,12 @@ risc_writemem(IOADDRESS io_base, vu32 addr, vu32 data, vu8 write_type)
#if 0
/*
- * static void risc_step(IOADDRESS io_base, vu32 count)
+ * static void risc_step(unsigned long io_base, vu32 count)
*
* Single step the RISC. NOTE: Do not force instruction into RISCIR!
*/
static void
-risc_step(IOADDRESS io_base, vu32 count)
+risc_step(unsigned long io_base, vu32 count)
{
vu32 c, d;
vu8 debugreg;
@@ -494,12 +494,12 @@ risc_step(IOADDRESS io_base, vu32 count)
/*
- * static void risc_forcestep(IOADDRESS io_base, vu32 instruction)
+ * static void risc_forcestep(unsigned long io_base, vu32 instruction)
*
* Single step RISC; force instruction; assumes RISC held.
*/
static void
-risc_forcestep(IOADDRESS io_base, vu32 instruction)
+risc_forcestep(unsigned long io_base, vu32 instruction)
{
vu32 c;
vu8 debugreg, stateindex;
@@ -525,12 +525,12 @@ risc_forcestep(IOADDRESS io_base, vu32 instruction)
/*
- * static void risc_continue(IOADDRESS io_base)
+ * static void risc_continue(unsigned long io_base)
*
* Turn off hold bit.
*/
static void
-risc_continue(IOADDRESS io_base)
+risc_continue(unsigned long io_base)
{
vu8 debugreg;
@@ -300,12 +300,12 @@ v1k_getriscprocs(verite_board_desc *boardDesc)
*/
/*
- * static void verite_iopoll(IOADDRESS port, vu32 data, vu32 mask)
+ * static void verite_iopoll(unsigned long port, vu32 data, vu32 mask)
*
* Loop on IO read until expected data is read or VERITE_MAX_POLLS is reached.
@@ -320,12 +320,12 @@ verite_iopoll(IOADDRESS port, vu32 data, vu32 mask)
/*
- * static void verite_iopoll8(IOADDRESS port, vu8 data, vu8 mask)
+ * static void verite_iopoll8(unsigned long port, vu8 data, vu8 mask)
*
* Loop on IO read until expected data is read or VERITE_MAX_POLLS is reached.
@@ -378,12 +378,12 @@ readRF(IOADDRESS io_base, vu8 index)
/*
- * static void writeRF(IOADDRESS io_base, vu8 index, vu32 data)
+ * static void writeRF(unsigned long io_base, vu8 index, vu32 data)
*
* Set RF register, being careful on how to set regs below 64.
@@ -445,12 +445,12 @@ risc_readmem(IOADDRESS io_base, vu32 addr, vu8 read_type)
/*
- * static vu32 risc_writemem(IOADDRESS io_base, vu32 addr, vu32 data, vu8 write_type)
+ * static vu32 risc_writemem(unsigned long io_base, vu32 addr, vu32 data, vu8 write_type)
*
* NOTE: Assumes RISC is in hold mode.
diff --git a/driver/xf86-video-rendition/src/vramdac.c b/driver/xf86-video-rendition/src/vramdac.c
index 7c8acbdfe..21c1df7dc 100644
--- a/driver/xf86-video-rendition/src/vramdac.c
+++ b/driver/xf86-video-rendition/src/vramdac.c
@@ -93,11 +93,11 @@
* local function prototypes
*/
-static void Bt485_write_masked(IOADDRESS port, vu8 reg, vu8 mask, vu8 data);
-static void Bt485_write_cmd3_masked(IOADDRESS port, vu8 mask, vu8 data);
+static void Bt485_write_masked(unsigned long port, vu8 reg, vu8 mask, vu8 data);
+static void Bt485_write_cmd3_masked(unsigned long port, vu8 mask, vu8 data);
#if 0
-static vu8 Bt485_read_masked(IOADDRESS port, vu8 reg, vu8 mask);
-static vu8 Bt485_read_cmd3_masked(IOADDRESS port, vu8 mask);
+static vu8 Bt485_read_masked(unsigned long port, vu8 reg, vu8 mask);
+static vu8 Bt485_read_cmd3_masked(unsigned long port, vu8 mask);
#endif
/*
@@ -159,7 +159,7 @@ int
verite_initdac(ScrnInfoPtr pScreenInfo, vu8 bpp, vu8 doubleclock)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base+RAMDACBASEADDR;
+ unsigned long iob=pRendition->board.io_base+RAMDACBASEADDR;
vu8 cmd0,cmd1,cmd2;
vu8 cmd3_data=0;
@@ -271,7 +271,7 @@ verite_enablecursor(ScrnInfoPtr pScreenInfo, int type, int size)
BT485_3_COLOR_CURSOR, BT485_X_WINDOW_CURSOR };
static vu8 csizes[]={ BT485_32_BY_32_CURSOR, BT485_64_BY_64_CURSOR };
- IOADDRESS iob=pRendition->board.io_base+RAMDACBASEADDR;
+ unsigned long iob=pRendition->board.io_base+RAMDACBASEADDR;
#ifdef DEBUG
ErrorF ("Rendition: Debug verite_enablecursor called type=0x%x\n",type);
@@ -304,7 +304,7 @@ void
verite_movecursor(ScrnInfoPtr pScreenInfo, vu16 x, vu16 y, vu8 xo, vu8 yo)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base+RAMDACBASEADDR;
+ unsigned long iob=pRendition->board.io_base+RAMDACBASEADDR;
x+=Cursor_size-xo;
y+=Cursor_size-yo;
@@ -327,7 +327,7 @@ void
verite_setcursorcolor(ScrnInfoPtr pScreenInfo, vu32 fg, vu32 bg)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base+RAMDACBASEADDR;
+ unsigned long iob=pRendition->board.io_base+RAMDACBASEADDR;
#ifdef DEBUG
ErrorF ("Rendition: Debug verite_setcursorcolor called FG=0x%x BG=0x%x\n",
@@ -374,7 +374,7 @@ verite_loadcursor(ScrnInfoPtr pScreenInfo, vu8 size, vu8 *cursorimage)
int c, bytes, row;
vu8 *src = cursorimage;
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base+RAMDACBASEADDR;
+ unsigned long iob=pRendition->board.io_base+RAMDACBASEADDR;
vu8 tmp;
vu8 memend; /* Added for byte-swap fix */
@@ -454,7 +454,7 @@ verite_setpalette(ScrnInfoPtr pScreenInfo, int numColors, int *indices,
LOCO *colors, VisualPtr pVisual)
{
renditionPtr pRendition = RENDITIONPTR(pScreenInfo);
- IOADDRESS iob=pRendition->board.io_base;
+ unsigned long iob=pRendition->board.io_base;
vu32 crtc_status;
int i, index;
@@ -485,12 +485,12 @@ verite_setpalette(ScrnInfoPtr pScreenInfo, int numColors, int *indices,
*/
/*
* static void Bt485_write_masked(IOADDRESS port, vu8 reg, vu8 mask, vu8 data)
*
*
*/
static void
-Bt485_write_masked(IOADDRESS port, vu8 reg, vu8 mask, vu8 data)
+Bt485_write_masked(unsigned long port, vu8 reg, vu8 mask, vu8 data)
{
vu8 tmp;
@@ -501,12 +501,12 @@ Bt485_write_masked(IOADDRESS port, vu8 reg, vu8 mask, vu8 data)
/*
* static void Bt485_write_cmd3_masked(IOADDRESS port, vu8 mask, vu8 data)
*
*
*/
static void
-Bt485_write_cmd3_masked(IOADDRESS port, vu8 mask, vu8 data)
+Bt485_write_cmd3_masked(unsigned long port, vu8 mask, vu8 data)
{
/*
* Bt485_write_masked(port, BT485_COMMAND_REG_0, 0x7f, 0x80);
@@ -522,24 +522,24 @@ Bt485_write_cmd3_masked(IOADDRESS port, vu8 mask, vu8 data)
#if 0
/*
* static vu8 Bt485_read_masked(IOADDRESS port, vu8 reg, vu8 mask)
*
*
*/
static vu8
-Bt485_read_masked(IOADDRESS port, vu8 reg, vu8 mask)
+Bt485_read_masked(unsigned long port, vu8 reg, vu8 mask)
{
return verite_in8(port+reg)&mask;
}
/*
- * static vu8 Bt485_read_cmd3_masked(IOADDRESS port, vu8 mask)
+ * static vu8 Bt485_read_cmd3_masked(unsigned long port, vu8 mask)
*
*
*/
static vu8
-Bt485_read_cmd3_masked(IOADDRESS port, vu8 mask)
+Bt485_read_cmd3_masked(unsigned long port, vu8 mask)
{
vu8 value;
@@ -485,12 +485,12 @@ verite_setpalette(ScrnInfoPtr pScreenInfo, int numColors, int *indices,
*/
/*
- * static void Bt485_write_masked(IOADDRESS port, vu8 reg, vu8 mask, vu8 data)
+ * static void Bt485_write_masked(unsigned long port, vu8 reg, vu8 mask, vu8 data)
*
*
@@ -501,12 +501,12 @@ Bt485_write_masked(IOADDRESS port, vu8 reg, vu8 mask, vu8 data)
/*
- * static void Bt485_write_cmd3_masked(IOADDRESS port, vu8 mask, vu8 data)
+ * static void Bt485_write_cmd3_masked(unsigned long port, vu8 mask, vu8 data)
*
*
@@ -522,24 +522,24 @@ Bt485_write_cmd3_masked(IOADDRESS port, vu8 mask, vu8 data)
#if 0
/*
- * static vu8 Bt485_read_masked(IOADDRESS port, vu8 reg, vu8 mask)
+ * static vu8 Bt485_read_masked(unsigned long port, vu8 reg, vu8 mask)
*
*